@@ -6,8 +6,7 @@ BEGIN { eval { require warnings; warnings->import } }
 use Getopt::Long ();
 
 use vars qw($VERSION);
-$VERSION = '1.00';	
-# VERSION 0.33 was in file File/Rename.pm
+$VERSION = '1.09';	
 
 eval{ Getopt::Long::Configure qw(
 	posix_default
@@ -16,6 +15,7 @@ eval{ Getopt::Long::Configure qw(
 ); 1 } or do { require Carp; Carp::carp($@) };
 
 sub GetOptions {
+    my ($no_code) = @_;
     my @expression;
     Getopt::Long::GetOptions(
 	'-v|verbose'	=> \my $verbose,
@@ -25,6 +25,7 @@ sub GetOptions {
 	'-h|?|help'	=> \my $help,
 	'-m|man'	=> \my $man,
 	'-V|version'	=> \my $version,
+	'-d|dir'	=> \my $dir,
 	'-e=s'		=> \@expression,
 	'-E=s'		=>
 	    sub {
@@ -39,11 +40,13 @@ sub GetOptions {
 	input_null	=> $null,
 	no_action	=> $nono,
 	over_write	=> $force,
+	filename_only	=> $dir,
 	show_help	=> $help,
 	show_manual	=> $man,
 	show_version	=> $version,
     };
     return $options if $help or $man or $version;
+    return $options if $no_code;
 	 
     if( @expression ) {
 	$options->{_code} = join "\n", @expression;
